==> cloudfoundry-client-2.22.0.BUILD-20171107.200356-8-sources.jar: org/cloudfoundry/client/v3/tasks/_CreateTaskRequest.java <==
/*
 * Copyright 2013-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v3.tasks;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.cloudfoundry.Nullable;
import org.immutables.value.Value;

/**
 * The request payload for the Create Task endpoint
 */
@Value.Immutable
abstract class _CreateTaskRequest {

    /**
     * The application id
     */
    @JsonIgnore
    abstract String getApplicationId();


    /**
     * The command that will be executed
     */
    @JsonProperty("command")
    abstract String getCommand();

    /**
     * Amount of disk to allocate for the task in MB
     */
    @JsonProperty("disk_in_mb")
    @Nullable
    abstract String getDiskInMb();

    /**
     * The id of the droplet that will be used to run the command
     */
    @JsonProperty("droplet_guid")
    @Nullable
    abstract String getDropletId();

    /**
     * The amount of memory to allocate for the task in MB
     */
    @JsonProperty("memory_in_mb")
    @Nullable
    abstract Integer getMemoryInMb();

    /**
     * The name of the task
     */
    @JsonProperty("name")
    @Nullable
    abstract String getName();

}

==> cloudfoundry-client-3.5.0.BUILD-20180201.140059-3-sources.jar: org/cloudfoundry/client/v3/tasks/_CreateTaskRequest.java <==
/*
 * Copyright 2013-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v3.tasks;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.cloudfoundry.Nullable;
import org.immutables.value.Value;

/**
 * The request payload for the Create Task endpoint
 */
@Value.Immutable
abstract class _CreateTaskRequest {

    /**
     * The application id
     */
    @JsonIgnore
    abstract String getApplicationId();

    /**
     * The command that will be executed
     */
    @JsonProperty("command")
    abstract String getCommand();

    /**
     * Amount of disk to allocate for the task in MB
     */
    @JsonProperty("disk_in_mb")
    @Nullable
    abstract Integer getDiskInMb();

    /**
     * The id of the droplet that will be used to run the command
     */
    @JsonProperty("droplet_guid")
    @Nullable
    abstract String getDropletId();

    /**
     * The amount of memory to allocate for the task in MB
     */
    @JsonProperty("memory_in_mb")
    @Nullable
    abstract Integer getMemoryInMb();

    /**
     * The name of the task
     */
    @JsonProperty("name")
    @Nullable
    abstract String getName();

}
